@@ -82,15 +82,9 @@ class Jump(GeneratorObject):
     def move_by(self, dx, dy):
         pass
 
-    def resize_by(self, dx, dy):
-        pass
-
     def point_in(self, x, y):
         return False
 
-    def change_type(self, new_type):
-        pass
-
     def get_rect(self, block_length=1, vertical=False) -> QRect:
         if vertical:
             return QRect(
