@@ -186,15 +186,9 @@ class MapObject(ObjectLike):
     def resize_to(self, x, y):
         return
 
-    def resize_by(self, dx, dy):
-        return
-
     def point_in(self, x, y):
         return self.rect.contains(x, y)
 
-    def change_type(self, new_type):
-        pass
-
     def get_rect(self):
         return self.rect
 
