@@ -48,10 +48,6 @@ class ObjectLike(ABC):
     def position(self, position: PositionProtocol) -> None:
         pass
 
-    @abstractmethod
-    def resize_by(self, dx, dy):
-        pass
-
     @abstractmethod
     def point_in(self, x, y):
         pass
@@ -70,10 +66,6 @@ class ObjectLike(ABC):
         else:
             return self.rect
 
-    @abstractmethod
-    def change_type(self, new_type):
-        pass
-
     @abstractmethod
     def __contains__(self, point):
         pass
