@@ -24,6 +24,11 @@ from foundry.game.gfx.objects.ObjectLike import (
     EXPANDS_HORIZ,
     EXPANDS_VERT,
 )
+from foundry.game.gfx.objects.util import (
+    decrement_type,
+    increment_type,
+    resize_level_object,
+)
 from foundry.game.level.Level import Level
 from foundry.game.level.LevelRef import LevelRef
 from foundry.game.level.WorldMap import WorldMap
@@ -320,7 +325,10 @@ class LevelView(QWidget):
 
         if obj is None:
             return
-        obj.increment_type() if y_delta > 0 else obj.decrement_type()
+        if y_delta > 0:
+            increment_type(obj)
+        else:
+            decrement_type(obj)
         obj.selected = True
 
     def sizeHint(self) -> QSize:
@@ -387,7 +395,7 @@ class LevelView(QWidget):
         selected_objects = self.get_selected_objects()
 
         for obj in selected_objects:
-            obj.resize_by(dx, dy)
+            resize_level_object(obj, dx, dy)
 
             self.level_ref.level.changed = True
 
